/**
 * filesystem.c - Tools for reading filesystem's serial numbers
 *
 * This file is part of Laite (http://iki.fi/zouppen/laite/)
 * Copyright 2005 Joel Lehtonen <joel dot lehtonen t iki dot fi>
 *
 * Laite is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * See COPYING
 */

#include <stdio.h>
#include <string.h>
#include "filesystem.h"

const int luku_OK     = 0;
const int luku_AVAUS  = 1;
const int luku_LYHYT  = 2;
const int luku_LUKU   = 3;

const size_t tietoSize = 512; // Boottisektorin koko

const osiotieto_t osiotieto[] =
{       
	{"fat12","FAT12", 5, 0x36, 0x27, 4},
	{"fat16","FAT16", 5, 0x36, 0x27, 4},
	{"fat32","FAT32", 5, 0x52, 0x43, 4},
	{"ntfs", "NTFS",  4, 0x03, 0x48, 4},
	{0,0,0,0}
};

int lueAlusta(char* osioData, const char* tiedosto, int length)
{
	FILE *osio = fopen(tiedosto,"rb");
	int vikailm = luku_OK;

	if (osio == NULL) return luku_AVAUS;

	if ( fread(osioData,length,1,osio) != 1 ) {
		if ( feof(osio) ) vikailm = luku_LYHYT;
		else vikailm = luku_LUKU;
		
		// Suoritus pttyy aina
	}
	fclose(osio);
	return vikailm;
}

const osiotieto_t* selvitaTyyppi(char *osioData)
{
	const osiotieto_t *tyyppi = osiotieto;
	do {
		char *oikea = tyyppi->tunniste;
		char *toinen = osioData+tyyppi->offFs;
		int oikeaPit = tyyppi->lenTunniste;
		int ero = memcmp(oikea,toinen,oikeaPit);

		if ( ero ) continue; // Takaisin alkuun
		
		return tyyppi;
	} while ( (++tyyppi)->lenTunniste ); // Kunnes nollatietue
	
	return NULL; // Ei lydy vastaavaa
}

void binhexConv(char* hex, char* bin, int count)
{
	char vastineet[] = "0123456789abcdef";
	char *hexPaikka = hex;
	
	// Little-endian-muunnos
	for (char* c = bin+count-1; c >= bin; c--) {
		*hexPaikka++ = vastineet[(*c & 0xf0) >> 4 ];
		*hexPaikka++ = vastineet[ *c & 0x0f ];
	}
	*hexPaikka = '\0'; // Loppumerkki
}

