/**
 * laitedump.c - Dumps device info (filesystem type and serial)
 *
 * This file is part of Laite (http://iki.fi/zouppen/laite/)
 * Copyright 2005 Joel Lehtonen <joel dot lehtonen t iki dot fi>
 *
 * Laite is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * See COPYING
 */

/* Zouppenin koodia */

#include <stdio.h>
#include <errno.h>
#include <string.h>
#include "pako.h"
#include "filesystem.h"

char defLinkName[] = "device_nickname";
const char devPath[] = "/dev/";

int main(int argc, char** argv)
{
	char* linkName = defLinkName;
	
	if (argc != 2 && argc != 3)
		virhePrint(1,"Usage: %s block_device [new_symlink]\n",argv[0]);
	
	if (argc == 3) {
		int devLen = strlen(devPath);
		linkName = argv[2];
		
		if (!strncmp(linkName,devPath,devLen)) // if starts with dev
			linkName += devLen; // skip that
	}

	char *fileName = argv[1];
	char bootSect[tietoSize];
	
	{
		int onnistuma = lueAlusta(bootSect,fileName,tietoSize);
		if ( onnistuma != luku_OK ) virhePrint(5,"Laitetta ei saatu luettua\n");
	}
	
	const osiotieto_t *tyyppi = selvitaTyyppi(bootSect);
	if (tyyppi == NULL ) virhePrint(3,"Osiotyyppi tuntematon\n");
	
	char *sarjanro = bootSect + tyyppi->offSerial;
	size_t lenSarjanro = tyyppi->lenSerial;

	{
		char heksa[lenSarjanro*2+1]; // Loppumerkki lasketaan mukaan
		binhexConv(heksa,sarjanro,lenSarjanro);
		printf("%s\t%s\t%s\n",linkName,tyyppi->nimi,heksa);
	}
	
	return 0;
}

